@@ -5,8 +5,8 @@ from datetime import datetime
 
 from CGPCLI.Errors import NotValidCGPStringError
 
-lbr_check_regex = re.compile(r"\".*\(.*\"", re.DOTALL)
-rbr_check_regex = re.compile(r"\".*\).*\"", re.DOTALL)
+lbr_check_regex = re.compile(r'.*\"[^)(]*(\()[^)(]*\".*', re.DOTALL)
+rbr_check_regex = re.compile(r'.*\"[^)(]*(\))[^)(]*\".*', re.DOTALL)
 
 def parse_to_CGP_object(python_object):
     result = ''
@@ -57,7 +57,7 @@ def parse_to_python_object(string, from_CLI=True):
 
                 lb_counter = el.count('(')
                 rb_counter = el.count(')')
-                
+
                 if lbr_check_regex.match(el):
                     lb_counter -= 1
                 if rbr_check_regex.match(el):
